@@ -1,20 +1,19 @@
 """Fox dimmable device implementation."""
 
-import logging
-from .fox_base_device import DeviceData, FoxBaseDevice
-from foxrestapiclient.connection.rest_api_client import RestApiClient
-from foxrestapiclient.connection.rest_api_responses import RestApiBaseResponse, RestApiBrightnessResponse
-from foxrestapiclient.connection.const import (
-    API_RESPONSE_STATUS_FAIL,
-    API_RESPONSE_STATUS_INVALID,
-    REQUEST_CHANNEL_KEY
-)
-from .const import (
-    API_DIMMABLE_GET_BRIGHTNESS,
-    API_DIMMABLE_SET_BRIGHTNESS,
-)
 import json
 
+from foxrestapiclient.connection import _LOGGER
+from foxrestapiclient.connection.const import (API_RESPONSE_STATUS_FAIL,
+                                               API_RESPONSE_STATUS_INVALID,
+                                               REQUEST_CHANNEL_KEY)
+from foxrestapiclient.connection.rest_api_client import RestApiClient
+from foxrestapiclient.connection.rest_api_responses import (
+    RestApiBaseResponse, RestApiBrightnessResponse)
+
+from .const import API_DIMMABLE_GET_BRIGHTNESS, API_DIMMABLE_SET_BRIGHTNESS
+from .fox_base_device import DeviceData, FoxBaseDevice
+
+
 class FoxDimmableDevice(FoxBaseDevice):
     """Fox Dimmable device implementation. Base class for any device with dimmable feature."""
 
@@ -23,14 +22,14 @@ class FoxDimmableDevice(FoxBaseDevice):
         super().__init__(device_data.name, device_data.host, device_data. api_key,
                         device_data.mac_addr, device_data.type)
         #Extened RestApi methods, specific for device
-        self.__device_api_client = self.__DeviceRestApiImplementer(super())
+        self.__device_api_client = self.DeviceRestApiImplementer(self._rest_api_client)
 
-    class __DeviceRestApiImplementer:
+    class DeviceRestApiImplementer:
         """Inner class with specific RestApi methods definition used by device."""
 
-        def __init__(self, restApiClient: RestApiClient) -> None:
+        def __init__(self, rest_api_client: RestApiClient) -> None:
             """Initialize object."""
-            self._restApiClient = restApiClient
+            self._rest_api_client = rest_api_client
 
         async def async_get_brightness_value(self, params) -> RestApiBrightnessResponse:
             """Get brightness value by given channel.
@@ -40,7 +39,7 @@ class FoxDimmableDevice(FoxBaseDevice):
             Return:
             RestApiBrightnessResponse
             """
-            device_response = await self._restApiClient.async_make_api_call_get(
+            device_response = await self._rest_api_client.async_make_api_call_get(
                 API_DIMMABLE_GET_BRIGHTNESS, params)
             if device_response is None:
                 return RestApiBrightnessResponse(status=API_RESPONSE_STATUS_FAIL)
@@ -54,7 +53,7 @@ class FoxDimmableDevice(FoxBaseDevice):
             Return:
             RestApiBaseResponse
             """
-            device_response = await self._restApiClient.async_make_api_call_get(
+            device_response = await self._rest_api_client.async_make_api_call_get(
                 API_DIMMABLE_SET_BRIGHTNESS, params)
             if device_response is None:
                 return RestApiBaseResponse(API_RESPONSE_STATUS_FAIL)
@@ -76,8 +75,7 @@ class FoxDimmableDevice(FoxBaseDevice):
                 REQUEST_CHANNEL_KEY: str(channel)
             }
         device_response = await self.__device_api_client.async_get_brightness_value(params)
-        if (device_response.status == API_RESPONSE_STATUS_FAIL or
-            device_response.status == API_RESPONSE_STATUS_INVALID):
+        if device_response.status in (API_RESPONSE_STATUS_FAIL, API_RESPONSE_STATUS_INVALID):
             return [0,0]
         values = []
         if device_response.brightness != -1:
@@ -88,7 +86,7 @@ class FoxDimmableDevice(FoxBaseDevice):
             values.append(device_response.channel_2_value)
         return values
 
-    async def async_update_channel_brightness(self, brightness: int, channel: int = None):
+    async def async_update_channel_brightness(self, brightness: int, channel: int = None) -> bool:
         """Set brightness value on device.
 
         Keyword arguments:
@@ -96,17 +94,20 @@ class FoxDimmableDevice(FoxBaseDevice):
         channel -- value from range <1-2> or None.
         """
         if brightness < 0 or brightness > 255:
-            logging.warning("Brightness passed to sync_update_channel_brightness() is out of range.")
-            return
+            _LOGGER.warning(
+                "Brightness passed to sync_update_channel_brightness() is out of range.")
+            return False
         if channel is not None and (channel < 0 or channel > 2):
-            logging.warning("Channel passed to sync_update_channel_brightness() is out of range.")
-            return
+            _LOGGER.warning(
+                "Channel passed to sync_update_channel_brightness() is out of range.")
+            return False
         params = {
-            "value": brightness, #Will be removed in next version.
+            "value": brightness
         }
         if channel is not None:
             params.update({REQUEST_CHANNEL_KEY: channel})
         device_response = await self.__device_api_client.async_set_brighntess_value(params)
-        if (device_response.status == API_RESPONSE_STATUS_FAIL or
-            device_response.status == API_RESPONSE_STATUS_INVALID):
-            logging.error("Setting brightness value in async_update_channel_brightness() failed.")
\ No newline at end of file
+        if device_response.status in (API_RESPONSE_STATUS_FAIL, API_RESPONSE_STATUS_INVALID):
+            _LOGGER.error("Setting brightness value in async_update_channel_brightness() failed.")
+        return True
+
